==> terrama2-4.1.0-ubuntu-16.04.tar.gz: opt/terrama2/4.1.0/include/terrama2/terrama2_config.hpp <==
/*
  Copyright (C) 2007 National Institute For Space Research (INPE) - Brazil.

  This file is part of TerraMA2 - a free and open source computational
  platform for analysis, monitoring, and alert of geo-environmental extremes.

  TerraMA2 is free software: you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation, either version 3 of the License,
  or (at your option) any later version.

  TerraMA2 is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with TerraMA2. See LICENSE. If not, write to
  TerraMA2 Team at <terrama2-team@dpi.inpe.br>.
*/

/*!
  \file terrama2/terrama2_config.hpp

  \brief TerraMA2 configuration options.

  \author Gilberto Ribeiro de Queiroz
 */

#ifndef __TERRAMA2_TERRAMA2_CONFIG_HPP__
#define __TERRAMA2_TERRAMA2_CONFIG_HPP__

#include <string>

const std::string TERRAMA2_DATA_DIR("/home/jenkins/workspace/terrama2-deb-generation/label/build-package/data");

// Database config for examples and unittests
const std::string TERRAMA2_DATABASE_USERNAME("postgres");

const std::string TERRAMA2_DATABASE_HOST("localhost");

const std::string TERRAMA2_DATABASE_PASSWORD("postgres");

const std::string TERRAMA2_DATABASE_PORT("5432");

const std::string TERRAMA2_DATABASE_DBNAME("terrama2");

const std::string TERRAMA2_CODEBASE_PATH("/home/jenkins/workspace/terrama2-deb-generation/label/ubuntu-ssh-jenkins/build/cmake/../..");

const std::string TERRAMA2_INSTALL_PREFIX_PATH("/opt/terrama2/4.1.0");

const std::string TERRAMA2_DIR_VAR_NAME("TERRAMA2_HOME");

/*!
  \def TM_DLL

  \brief It links correctly the TerraMa2 libraries in Windows systems.
 */

#ifdef WIN32
  #define TM_DLL_EXPORT __declspec(dllexport)
  #define TM_DLL_IMPORT __declspec(dllimport)
#else
  #define TM_DLL_EXPORT
  #define TM_DLL_IMPORT
#endif

#endif // __TERRAMA2_TERRAMA2_CONFIG_HPP__

==> terrama2-4.1.1-ubuntu-16.04.tar.gz: opt/terrama2/4.1.1/include/terrama2/terrama2_config.hpp <==
/*
  Copyright (C) 2007 National Institute For Space Research (INPE) - Brazil.

  This file is part of TerraMA2 - a free and open source computational
  platform for analysis, monitoring, and alert of geo-environmental extremes.

  TerraMA2 is free software: you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation, either version 3 of the License,
  or (at your option) any later version.

  TerraMA2 is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with TerraMA2. See LICENSE. If not, write to
  TerraMA2 Team at <terrama2-team@dpi.inpe.br>.
*/

/*!
  \file terrama2/terrama2_config.hpp

  \brief TerraMA2 configuration options.

  \author Gilberto Ribeiro de Queiroz
 */

#ifndef __TERRAMA2_TERRAMA2_CONFIG_HPP__
#define __TERRAMA2_TERRAMA2_CONFIG_HPP__

#include <string>

const std::string TERRAMA2_DATA_DIR("/home/jenkins/workspace/terrama2-final-user-deb-generation/label/build-package/data");

// Database config for examples and unittests
const std::string TERRAMA2_DATABASE_USERNAME("postgres");

const std::string TERRAMA2_DATABASE_HOST("localhost");

const std::string TERRAMA2_DATABASE_PASSWORD("postgres");

const std::string TERRAMA2_DATABASE_PORT("5432");

const std::string TERRAMA2_DATABASE_DBNAME("terrama2");

const std::string TERRAMA2_CODEBASE_PATH("/home/jenkins/workspace/terrama2-final-user-deb-generation/label/ubuntu-ssh-jenkins/build/cmake/../..");

const std::string TERRAMA2_INSTALL_PREFIX_PATH("/opt/terrama2/4.1.1");

const std::string TERRAMA2_DIR_VAR_NAME("TERRAMA2_HOME");

/*!
  \def TM_DLL

  \brief It links correctly the TerraMa2 libraries in Windows systems.
 */

#ifdef WIN32
  #define TM_DLL_EXPORT __declspec(dllexport)
  #define TM_DLL_IMPORT __declspec(dllimport)
#else
  #define TM_DLL_EXPORT
  #define TM_DLL_IMPORT
#endif

#endif // __TERRAMA2_TERRAMA2_CONFIG_HPP__
